.. image:: img/staircasewide.png
   :width: 80%
   :alt: staircase logo
   :align: center

.. rst-class:: center

**Date**: |today| **Version**: |version|

.. rst-class:: center

**Useful links**:
`Source Repository <https://github.com/venaturum/staircase>`__ |
`Issues & Ideas <https://github.com/venaturum/staircase/issues>`__ 

.. rst-class:: center

An open source library for modelling step functions
  

Contents
==================

.. toctree::
   :maxdepth: 2
   
   install.rst
   getting_started.rst
   resources.rst
   api.rst 
   contributing.rst

   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
